@@ -180,18 +180,12 @@ class DetectionModel:
         return self._original_predictions
 
 
-@check_requirements(["torch", "mmdet", "mmcv"])
 class MmdetDetectionModel(DetectionModel):
     def load_model(self):
         """
         Detection model is initialized and set to self.model.
         """
-        try:
-            import mmdet
-        except ImportError:
-            raise ImportError(
-                'Please run "pip install -U mmcv mmdet" ' "to install MMDetection first for MMDetection inference."
-            )
+        check_requirements(["torch", "mmdet", "mmcv"])
 
         from mmdet.apis import init_detector
 
@@ -221,12 +215,7 @@ class MmdetDetectionModel(DetectionModel):
             image: np.ndarray
                 A numpy array that contains the image to be predicted. 3 channel image should be in RGB order.
         """
-        try:
-            import mmdet
-        except ImportError:
-            raise ImportError(
-                'Please run "pip install -U mmcv mmdet" ' "to install MMDetection first for MMDetection inference."
-            )
+        check_requirements(["torch", "mmdet", "mmcv"])
 
         # Confirm model is loaded
         if self.model is None:
@@ -368,12 +357,13 @@ class MmdetDetectionModel(DetectionModel):
         self._object_prediction_list_per_image = object_prediction_list_per_image
 
 
-@check_requirements(["torch", "yolov5"])
 class Yolov5DetectionModel(DetectionModel):
     def load_model(self):
         """
         Detection model is initialized and set to self.model.
         """
+        check_requirements(["torch", "yolov5"])
+
         import yolov5
 
         try:
@@ -511,9 +501,10 @@ class Yolov5DetectionModel(DetectionModel):
         self._object_prediction_list_per_image = object_prediction_list_per_image
 
 
-@check_requirements(["torch", "detectron2"])
 class Detectron2DetectionModel(DetectionModel):
     def load_model(self):
+        check_requirements(["torch", "detectron2"])
+
         from detectron2.config import get_cfg
         from detectron2.data import MetadataCatalog
         from detectron2.engine import DefaultPredictor
@@ -673,7 +664,6 @@ class Detectron2DetectionModel(DetectionModel):
         self._object_prediction_list_per_image = object_prediction_list_per_image
 
 
-@check_requirements(["torch", "transformers"])
 class HuggingfaceDetectionModel(DetectionModel):
     import torch
 
@@ -691,6 +681,8 @@ class HuggingfaceDetectionModel(DetectionModel):
         load_at_init: bool = True,
         image_size: int = None,
     ):
+        check_requirements(["torch", "transformers"])
+
         self._feature_extractor = feature_extractor
         self._image_shapes = []
         super().__init__(
@@ -722,6 +714,8 @@ class HuggingfaceDetectionModel(DetectionModel):
         return self.model.config.num_labels
 
     def load_model(self):
+        check_requirements(["torch", "transformers"])
+
         from transformers import AutoFeatureExtractor, AutoModelForObjectDetection
 
         model = AutoModelForObjectDetection.from_pretrained(self.model_path)
@@ -862,7 +856,6 @@ class HuggingfaceDetectionModel(DetectionModel):
         self._object_prediction_list_per_image = object_prediction_list_per_image
 
 
-@check_requirements(["torch", "torchvision"])
 class TorchVisionDetectionModel(DetectionModel):
     def __init__(
         self,
@@ -892,6 +885,8 @@ class TorchVisionDetectionModel(DetectionModel):
         )
 
     def load_model(self):
+        check_requirements(["torch", "torchvision"])
+
         import torch
 
         from sahi.utils.torchvision import MODEL_NAME_TO_CONSTRUCTOR
@@ -941,6 +936,7 @@ class TorchVisionDetectionModel(DetectionModel):
             model: Any
                 A TorchVision model
         """
+        check_requirements(["torch", "torchvision"])
 
         model.eval()
         self.model = model.to(self.device)
